============================
Fundamentals of Data Science
============================


.. image:: https://img.shields.io/pypi/v/fundamentals_of_data_science.svg
        :target: https://pypi.python.org/pypi/fundamentals_of_data_science

.. image:: https://img.shields.io/travis/fundamentals-of-data-science/ds-fundamentals-python.svg
        :target: https://travis-ci.org/fundamentals-of-data-science/ds-fundamentals-python

.. image:: https://readthedocs.org/projects/fundamentals-of-data-science/badge/?version=latest
        :target: https://fundamentals-of-data-science.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status


.. image:: https://pyup.io/repos/github/fundamentals-of-data-science/ds-fundamentals-python/shield.svg
     :target: https://pyup.io/repos/github/fundamentals-of-data-science/ds-fundamentals-python/
     :alt: Updates



Companion Python package for Fundamentals of Data Science.


* Free software: MIT license
* Documentation: https://fundamentals-of-data-science.readthedocs.io.


Features
--------

* TODO

Credits
-------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
